@@ -47,30 +47,30 @@ class DeleteOvercloud(command.Command):
             raise oscexc.CommandError(
                 "You must specify a stack name")
 
-    def _stack_delete(self, clients, stack_name):
+    def _plan_undeploy(self, clients, stack_name):
         orchestration_client = clients.orchestration
 
-        print("Deleting stack {s}...".format(s=stack_name))
+        print("Undeploying stack {s}...".format(s=stack_name))
         stack = utils.get_stack(orchestration_client, stack_name)
         if stack is None:
             self.log.warning("No stack found ('{s}'), skipping delete".
                              format(s=stack_name))
         else:
             try:
-                stack_management.delete_stack(
+                stack_management.plan_undeploy(
                     clients,
-                    stack=stack.id
+                    plan=stack.stack_name
                 )
             except Exception as e:
                 raise oscexc.CommandError(
                     "Error occurred during stack delete {}".
                     format(e))
 
-    def _plan_delete(self, workflow_client, stack_name):
+    def _plan_delete(self, clients, stack_name):
         print("Deleting plan {s}...".format(s=stack_name))
         try:
             plan_management.delete_deployment_plan(
-                workflow_client,
+                clients,
                 container=stack_name)
         except Exception as err:
             raise oscexc.CommandError(
@@ -90,8 +90,7 @@ class DeleteOvercloud(command.Command):
                 raise oscexc.CommandError("Action not confirmed, exiting.")
 
         clients = self.app.client_manager
-        workflow_client = clients.workflow_engine
 
-        self._stack_delete(clients, parsed_args.stack)
-        self._plan_delete(workflow_client, parsed_args.stack)
+        self._plan_undeploy(clients, parsed_args.stack)
+        self._plan_delete(clients, parsed_args.stack)
         print("Success.")
