@@ -89,7 +89,6 @@ USER_HOME = os.environ.get('HOME', '')
 TELEMETRY_DOCKER_ENV_YAML = [
     'environments/services/undercloud-gnocchi.yaml',
     'environments/services/undercloud-aodh.yaml',
-    'environments/services/undercloud-panko.yaml',
     'environments/services/undercloud-ceilometer.yaml']
 
 CONF = cfg.CONF
@@ -223,6 +222,7 @@ def _generate_inspection_subnets():
         env_dict['netmask'] = str(netaddr.IPNetwork(s.cidr).netmask)
         env_dict['gateway'] = s.gateway
         env_dict['host_routes'] = s.host_routes
+        env_dict['mtu'] = CONF.local_mtu
         env_list.append(env_dict)
     return env_list
 
@@ -331,6 +331,7 @@ def _process_network_args(env):
     env['IronicInspectorSubnets'] = _generate_inspection_subnets()
     env['ControlPlaneStaticRoutes'] = _generate_subnets_static_routes()
     env['UndercloudCtlplaneSubnets'] = {}
+    env['UndercloudCtlplaneIPv6AddressMode'] = CONF['ipv6_address_mode']
     for subnet in CONF.subnets:
         s = CONF.get(subnet)
         env['UndercloudCtlplaneSubnets'][subnet] = {
@@ -358,6 +359,7 @@ def _process_network_args(env):
         env['MemcachedIPv6'] = True
         env['RedisIPv6'] = True
         env['MysqlIPv6'] = True
+        env['IronicIpVersion'] = '6'
 
     # We do not use undercloud ips for env, but just validate the configured
     # value here.
@@ -375,9 +377,10 @@ def _process_network_args(env):
             raise exceptions.InvalidConfiguration(msg)
 
 
-def prepare_undercloud_deploy(upgrade=False, no_validations=False,
+def prepare_undercloud_deploy(upgrade=False, no_validations=True,
                               verbose_level=1, yes=False,
-                              force_stack_update=False, dry_run=False):
+                              force_stack_update=False, dry_run=False,
+                              inflight=False):
     """Prepare Undercloud deploy command based on undercloud.conf"""
 
     env_data = {}
@@ -756,6 +759,9 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=False,
         deploy_args += ['-e', os.path.join(
             tht_templates, "environments/tripleo-validations.yaml")]
 
+    if inflight:
+        deploy_args.append('--inflight-validations')
+
     if CONF.get('custom_env_files'):
         for custom_file in CONF['custom_env_files']:
             deploy_args += ['-e', custom_file]
